document.addEventListener('DOMContentLoaded', () => {
  document.getElementById('version').textContent = chrome.runtime.getManifest().version; // הצגת גרסת התוסף
  document.getElementById('greeting').textContent = getGreeting(); // הצגת ברכה לפי השעה

  document.getElementById('settingsButton').addEventListener('click', () => chrome.runtime.openOptionsPage()); // פתיחת דף ההגדרות
  document.getElementById('refreshButton').addEventListener('click', checkNotifications); // רענון ההתראות

  const muteButton = document.getElementById('muteButton');
  updateMuteButtonState(); // עדכון מצב כפתור ההשתקה
  muteButton.addEventListener('click', toggleMute); // טיפול בלחיצה על כפתור ההשתקה

  populateSiteList(); // מילוי רשימת האתרים
  checkNotifications(); // סנכרון מלא של כל ההתראות עם השרת בעת פתיחת הפופאפ
});

// פונקציה שמחזירה ברכה לפי השעה
function getGreeting() {
  const now = new Date();
  const hour = now.getHours();
  if (hour >= 5 && hour < 12) return 'בוקר טוב';
  if (hour >= 12 && hour < 17) return 'צהריים טובים';
  if (hour >= 17 && hour < 21) return 'ערב טוב';
  return 'לילה טוב';
}

// פונקציה שמעדכנת את מצב כפתור ההשתקה
async function updateMuteButtonState() {
  const muteButton = document.getElementById('muteButton');
  const muteState = await chrome.storage.local.get('muteUntil');
  const muteUntil = muteState.muteUntil;

  if (muteUntil && new Date(muteUntil) > new Date()) {
    muteButton.classList.add('muted');
    muteButton.textContent = 'בטל השתקה';
  } else {
    muteButton.classList.remove('muted');
    muteButton.textContent = 'השתק לשעה';
  }
}

// פונקציה שמשנה את מצב ההשתקה
async function toggleMute() {
  const muteState = await chrome.storage.local.get('muteUntil');
  const currentTime = new Date();

  if (muteState.muteUntil && new Date(muteState.muteUntil) > currentTime) {
    await chrome.storage.local.remove('muteUntil');
  } else {
    const muteUntil = new Date(currentTime.getTime() + 60 * 60 * 1000); // השתקה לשעה
    await chrome.storage.local.set({ muteUntil: muteUntil.toISOString() });
  }
  updateMuteButtonState();
}

// פונקציה שממלאת את רשימת האתרים בצד
async function populateSiteList() {
  const siteList = document.getElementById('site-list');
  const sites = await chrome.storage.sync.get('sites').then(data => data.sites || getDefaultSites());
  const enabledSites = sites.filter(site => site.enabled);

  const state = await chrome.storage.local.get('notificationsState');
  const siteNotifications = state.notificationsState?.siteNotifications || {};

  for (const site of enabledSites) {
    const unreadCount = siteNotifications[site.name] || 0;
    const li = document.createElement('li');
    li.innerHTML = `${site.name} <span class="unread-count">${unreadCount > 0 ? unreadCount : ''}</span>`;
    li.dataset.siteUrl = site.url;
    li.dataset.siteName = site.name;
    li.addEventListener('click', () => {
      document.querySelectorAll('#site-list li').forEach(item => item.classList.remove('active'));
      li.classList.add('active');
      displayNotifications(site.url, site.name);
    });
    siteList.appendChild(li);
  }

  if (enabledSites.length > 0) {
    siteList.querySelector('li').click(); // בחר את האתר הראשון כברירת מחדל
  }
}

// פונקציה שמחזירה את רשימת האתרים ברירת המחדל
function getDefaultSites() {
  return [
    { url: 'https://tchumim.com', name: 'תחומים', enabled: true },
    { url: 'https://mitmachim.top', name: 'מתמחים', enabled: true },
    { url: 'https://f2.freeivr.co.il', name: 'פורום ימות המשיח', enabled: true },
    { url: 'https://forum-office.co.il', name: 'פורום אופיס', enabled: true },
    { url: 'https://forum.netfree.link', name: 'פורום נטפרי', enabled: true },
    { url: 'https://forum.safera.co.il', name: 'פורום סייפר', enabled: true },
    { url: 'https://rechavimzelaze.ovh', name: 'רכבים זה לזה', enabled: true },
    { url: 'https://hamusicay.com', name: 'המוזיקאי', enabled: true },
    { url: 'https://miktzav.com', name: 'מקצב', enabled: true }
  ];
}

// פונקציה שבודקת התראות ומרעננת את הפופאפ
async function checkNotifications() {
  const notificationsDiv = document.getElementById('notifications');
  notificationsDiv.innerHTML = '<div class="loading"><div class="spinner"></div><div>טוען...</div></div>';

  // בדיקה מלאה של כל האתרים
  const sites = await chrome.storage.sync.get('sites').then(data => data.sites || getDefaultSites());
  const enabledSites = sites.filter(site => site.enabled);
  let totalUnreadCount = 0;
  let siteNotifications = {};

  for (const site of enabledSites) {
    try {
      const response = await fetch(`${site.url}/api/notifications`, { credentials: 'include' });
      const data = await response.json();
      if (!data.status || data.status.code !== "not-authorised") {
        const unreadCount = data.notifications.filter(n => !n.read).length;
        totalUnreadCount += unreadCount;
        siteNotifications[site.name] = unreadCount;
      } else {
        siteNotifications[site.name] = 0;
      }
    } catch (error) {
      siteNotifications[site.name] = 0; // אם יש שגיאה, סמן 0 התראות
    }
  }

  // עדכון מצב ההתראות באחסון המקומי
  const newState = {
    totalCount: totalUnreadCount,
    siteNotifications: siteNotifications,
    lastChecked: new Date().toISOString()
  };
  await chrome.storage.local.set({ notificationsState: newState });

  // עדכון ה-Badge והרשימה בצד שמאל
  updateBadge(totalUnreadCount);
  const siteItems = document.querySelectorAll('#site-list li');
  for (const li of siteItems) {
    const unreadCount = siteNotifications[li.dataset.siteName] || 0;
    li.querySelector('.unread-count').textContent = unreadCount > 0 ? unreadCount : '';
  }

  // עדכון התצוגה של האתר הפעיל
  const activeSite = document.querySelector('#site-list li.active');
  if (activeSite) {
    await displayNotifications(activeSite.dataset.siteUrl, activeSite.dataset.siteName);
  }
}

// פונקציה שמעדכנת את ה-Badge עם מספר ההתראות
function updateBadge(count) {
  if (count > 0) {
    chrome.action.setBadgeText({ text: count.toString() });
    chrome.action.setBadgeBackgroundColor({ color: '#FF0000' });
  } else {
    chrome.action.setBadgeText({ text: '' });
  }
}

// פונקציה שמציגה את ההתראות של אתר מסוים
async function displayNotifications(siteUrl, siteName) {
  const notificationsDiv = document.getElementById('notifications');
  try {
    const response = await fetch(`${siteUrl}/api/notifications`, { credentials: 'include' });
    const data = await response.json();

    if (data.status && data.status.code === "not-authorised") {
      notificationsDiv.innerHTML = '<div class="disconnected-sites">אתר זה מנותק. <a href="' + siteUrl + '/login" target="_blank">התחבר</a></div>';
      return;
    }

    const unread = data.notifications.filter(n => !n.read);
    if (unread.length === 0) {
      notificationsDiv.innerHTML = '<div class="no-notifications">אין התראות חדשות</div>';
      return;
    }

    notificationsDiv.innerHTML = `<div class="notification-source">${siteName}: <span class="notification-count">${unread.length} התראות חדשות</span></div>`;
    unread.forEach(n => {
      const notificationItem = createNotificationHTML(n, siteUrl, siteName);
      notificationsDiv.appendChild(notificationItem);
    });

    addNotificationClickListeners();
  } catch (error) {
    notificationsDiv.innerHTML = '<div class="no-notifications">שגיאה בטעינת ההתראות</div>';
  }
}

// פונקציה שיוצרת HTML עבור התראה בודדת
function createNotificationHTML(notification, siteUrl, siteName) {
  const localTime = new Date(notification.datetimeISO).toLocaleString('he-IL', {
    timeZone: 'Asia/Jerusalem',
    year: 'numeric',
    month: 'numeric',
    day: 'numeric',
    hour: 'numeric',
    minute: 'numeric'
  });

  const div = document.createElement('div');
  div.className = 'notification-item';
  div.innerHTML = `
    <a href="${siteUrl}${notification.path}" target="_blank" class="notification-link" data-notification-id="${notification.nid}">
      <div class="notification-content">${notification.bodyShort}</div>
      <div class="notification-time">${localTime}</div>
    </a>
    <a href="${siteUrl}${notification.path}" class="notification-mark-read" data-notification-id="${notification.nid}">
      <div class="notification-icon">
        <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor">
          <path stroke-linecap="round" stroke-linejoin="round" d="M9 12.75 11.25 15 15 9.75M21 12a9 9 0 1 1-18 0 9 9 0 0 1 18 0Z" />
        </svg>
      </div>
    </a>
  `;
  return div;
}

// פונקציה שמוסיפה מאזינים ללחיצות על התראות
function addNotificationClickListeners() {
  document.querySelectorAll('.notification-link').forEach(link => {
    link.addEventListener('click', async (event) => {
      event.preventDefault(); // מניעת פתיחה אוטומטית של טאב חדש
      const notificationId = link.dataset.notificationId;
      const siteName = document.querySelector('#site-list li.active').dataset.siteName;
      const notificationUrl = link.href; // ה-URL המלא של ההתראה (למשל, https://mitmachim.top/topic/123)

      // שליפת ה-base URL של הפורום (למשל, https://mitmachim.top)
      const baseUrl = new URL(notificationUrl).origin;

      // חיפוש טאבים פעילים (בחלון שבחזית) שמתאימים ל-base URL
      chrome.tabs.query({ url: `${baseUrl}/*`, active: true, currentWindow: true }, async (activeTabs) => {
        if (activeTabs.length > 0) {
          // אם יש טאב פעיל בחלון הנוכחי, עדכן אותו
          const activeTab = activeTabs[0];
          await chrome.tabs.update(activeTab.id, { active: true, url: notificationUrl });
          window.close(); // סגור את הפופאפ לאחר שינוי הטאב
        } else {
          // אם אין טאב פעיל בחלון הנוכחי, חפש טאבים קיימים בכל החלונות
          chrome.tabs.query({ url: `${baseUrl}/*` }, async (allTabs) => {
            if (allTabs.length > 0) {
              // אם יש טאב קיים (אבל לא פעיל), הפעל את הטאב הראשון שנמצא
              const existingTab = allTabs[0];
              await chrome.tabs.update(existingTab.id, { active: true, url: notificationUrl });
              window.close(); // סגור את הפופאפ לאחר שינוי הטאב
            } else {
              // אם אין טאב קיים בכלל, פתח טאב חדש
              window.open(notificationUrl, '_blank');
              window.close(); // סגור את הפופאפ לאחר פתיחת הטאב
            }
          });
        }
      });

      link.parentElement.querySelector('.notification-icon').classList.add('read'); // סמן כנקרא
      chrome.runtime.sendMessage({
        action: 'markNotificationRead',
        siteName: siteName,
        notificationId: notificationId
      });

      const li = document.querySelector(`#site-list li[data-site-name="${siteName}"]`);
      const state = await chrome.storage.local.get('notificationsState');
      const siteNotifications = state.notificationsState?.siteNotifications || {};
      const currentCount = siteNotifications[siteName] || 0;
      const newCount = Math.max(currentCount - 1, 0);
      li.querySelector('.unread-count').textContent = newCount > 0 ? newCount : '';

      setTimeout(() => link.parentElement.remove(), 500); // הסר את ההתראה לאחר אנימציה
    });
  });

  document.querySelectorAll('.notification-mark-read').forEach(link => {
    link.addEventListener('click', async (event) => {
      event.preventDefault();
      const url = link.href;
      const notificationId = link.dataset.notificationId;
      const siteName = document.querySelector('#site-list li.active').dataset.siteName;

      const response = await fetch(url, { credentials: 'include' });
      if (response.ok) {
        link.querySelector('.notification-icon').classList.add('read'); // סמן כנקרא
        chrome.runtime.sendMessage({
          action: 'markNotificationRead',
          siteName: siteName,
          notificationId: notificationId
        });

        const li = document.querySelector(`#site-list li[data-site-name="${siteName}"]`);
        const state = await chrome.storage.local.get('notificationsState');
        const siteNotifications = state.notificationsState?.siteNotifications || {};
        const currentCount = siteNotifications[siteName] || 0;
        const newCount = Math.max(currentCount - 1, 0);
        li.querySelector('.unread-count').textContent = newCount > 0 ? newCount : '';

        setTimeout(() => link.parentElement.remove(), 500); // הסר את ההתראה לאחר אנימציה
      }
    });
  });
}

// הקשבה לשינויים ב-storage כדי לעדכן את ה-Badge
chrome.storage.onChanged.addListener((changes, namespace) => {
  if (namespace === 'local' && changes.notificationsState) {
    const state = changes.notificationsState.newValue;
    const siteItems = document.querySelectorAll('#site-list li');
    let totalUnread = 0;
    for (const li of siteItems) {
      const unreadCount = state.siteNotifications?.[li.dataset.siteName] || 0;
      li.querySelector('.unread-count').textContent = unreadCount > 0 ? unreadCount : '';
      totalUnread += unreadCount;
    }
    chrome.runtime.sendMessage({ action: 'updateBadge', totalUnread: totalUnread });
  }
});